'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _Network = require('cashlib/lib/Network');

var _Network2 = _interopRequireDefault(_Network);

var _List = require('tooey/lib/List');

var _List2 = _interopRequireDefault(_List);

var _Menu = require('tooey/lib/Menu');

var _Menu2 = _interopRequireDefault(_Menu);

var _MenuItem = require('tooey/lib/MenuItem');

var _MenuItem2 = _interopRequireDefault(_MenuItem);

var _ViewBase = require('tooey/lib/ViewBase');

var _ViewBase2 = _interopRequireDefault(_ViewBase);

var _Tab = require('tooey/lib/Tab');

var _Tab2 = _interopRequireDefault(_Tab);

var _Connection = require('../../model/Connection');

var _Connection2 = _interopRequireDefault(_Connection);

var _MainMenu = require('./MainMenu');

var _MainMenu2 = _interopRequireDefault(_MainMenu);

var _NetworkSelection = require('./NetworkSelection');

var _NetworkSelection2 = _interopRequireDefault(_NetworkSelection);

var _state = require('../../model/state');

var _state2 = _interopRequireDefault(_state);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class ConnectionHistory extends _ViewBase2.default {

  constructor(tab) {
    super('Recent Connections');
    this._tab = tab;

    // Create menu
    this._connectItem = new _MenuItem2.default('C', 'Connect', 'Connect to selected network', this.connectToSelected.bind(this));
    this._menu = new _Menu2.default(tab, [this._connectItem, new _MenuItem2.default('N', 'New', 'Create new connection', this.toNetworkSelection.bind(this))], false);

    // Get history
    this._history = _Connection2.default.getHistory();
    if (!this._history.length) {
      throw new Error('No recent connections found.');
    }

    // Create list columns
    const columns = [{
      heading: 'Network',
      width: 10,
      value: history => history.network
    }, {
      heading: 'Host',
      width: 30,
      value: history => `${history.host}:${history.port.toString()}`
    }, {
      heading: 'Authentication',
      width: 40,
      value: history => history.cookieFile || `${history.user}:${'*'.repeat(history.password.length)}`
    }];

    // Create list
    this._list = new _List2.default(tab, columns, this._history, {
      menu: this._menu,
      rowSelection: true,
      onSelect: this.onListSelect.bind(this)
    });
  }

  async onListSelect() {
    this._menu.setSelectedItem(this._connectItem.key);
  }

  async toNetworkSelection() {
    this._tab.replaceView(new _NetworkSelection2.default(this._tab));
  }

  async connectToSelected() {
    try {
      const selectedIndex = this._list.selectedRowIndex;
      const history = this._history[selectedIndex];
      const network = _Network2.default.fromString(history.network);
      const connection = new _Connection2.default(network);
      connection.host = history.host;
      connection.port = history.port;
      connection.cookieFile = history.cookieFile;
      connection.user = history.user;
      connection.password = history.password;
      _state2.default.connection = connection;
      await connection.connect();
      this._tab.stateMessage = _state2.default.connection.network.label;
      this._list.setData(_Connection2.default.getHistory());
      this._tab.pushView(new _MainMenu2.default(this._tab));
    } catch (err) {
      this._tab.setError(err.message);
    }
  }

  render() {
    // Render list first
    this._list.render();

    // Render menu last so cursor position is left in correct position
    this._menu.render(false);
  }

  async handle(key) {
    let handled = false;
    handled = await this._menu.handle(key);
    if (!handled) {
      handled = await this._list.handle(key);
    }
    return handled;
  }
}
exports.default = ConnectionHistory;