'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _MenuForm = require('tooey/lib/MenuForm');

var _MenuForm2 = _interopRequireDefault(_MenuForm);

var _ViewBase = require('tooey/lib/ViewBase');

var _ViewBase2 = _interopRequireDefault(_ViewBase);

var _MenuItem = require('tooey/lib/MenuItem');

var _MenuItem2 = _interopRequireDefault(_MenuItem);

var _Tab = require('tooey/lib/Tab');

var _Tab2 = _interopRequireDefault(_Tab);

var _MainMenu = require('./MainMenu');

var _MainMenu2 = _interopRequireDefault(_MainMenu);

var _state = require('../../model/state');

var _state2 = _interopRequireDefault(_state);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const fieldIdx = {
  HOST: 0,
  PORT: 1,
  COOKIE: 2,
  USER: 3,
  PASSWORD: 4
};

class ConnectionSettings extends _ViewBase2.default {

  constructor(tab) {
    super('Connection Settings');
    this._tab = tab;

    // Form fields
    const fields = [];
    fields[fieldIdx.HOST] = { label: 'Host', default: _state2.default.connection.host, type: 'string' };
    fields[fieldIdx.PORT] = { label: 'Port', default: _state2.default.connection.port.toString(), type: 'integer' };
    fields[fieldIdx.COOKIE] = { label: 'Cookie file', default: _state2.default.connection.cookieFile, type: 'string' };
    fields[fieldIdx.USER] = { label: 'User', default: _state2.default.connection.user, type: 'string' };
    fields[fieldIdx.PASSWORD] = { label: 'Password', default: _state2.default.connection.password, type: 'password' };

    // Menu items
    const menuItems = [new _MenuItem2.default('C', 'Connect', 'Connect to the node', this.connect.bind(this))];

    this._menuForm = new _MenuForm2.default(tab, fields, menuItems);
  }

  async connect() {
    try {
      // Update connection settings from form and connect
      const { fields } = this._menuForm.form;
      _state2.default.connection.host = fields[fieldIdx.HOST].input.value;
      _state2.default.connection.port = parseInt(fields[fieldIdx.PORT].input.value, 10);
      _state2.default.connection.cookieFile = fields[fieldIdx.COOKIE].input.value;
      _state2.default.connection.user = fields[fieldIdx.USER].input.value;
      _state2.default.connection.password = fields[fieldIdx.PASSWORD].input.value;
      await _state2.default.connection.connect();
      this._tab.stateMessage = _state2.default.connection.network.label;
      this._tab.pushView(new _MainMenu2.default(this._tab));
    } catch (err) {
      this._tab.setError(err.message);
    }
  }

  async handle(key) {
    return this._menuForm.handle(key);
  }

  render() {
    this._menuForm.render();
  }
}
exports.default = ConnectionSettings;