'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _Network = require('cashlib/lib/Network');

var _Network2 = _interopRequireDefault(_Network);

var _ViewBase = require('tooey/lib/ViewBase');

var _ViewBase2 = _interopRequireDefault(_ViewBase);

var _List = require('tooey/lib/List');

var _List2 = _interopRequireDefault(_List);

var _Menu = require('tooey/lib/Menu');

var _Menu2 = _interopRequireDefault(_Menu);

var _MenuItem = require('tooey/lib/MenuItem');

var _MenuItem2 = _interopRequireDefault(_MenuItem);

var _Tab = require('tooey/lib/Tab');

var _Tab2 = _interopRequireDefault(_Tab);

var _Connection = require('../../model/Connection');

var _Connection2 = _interopRequireDefault(_Connection);

var _ConnectionSettings = require('./ConnectionSettings');

var _ConnectionSettings2 = _interopRequireDefault(_ConnectionSettings);

var _ConnectionHistory = require('./ConnectionHistory');

var _ConnectionHistory2 = _interopRequireDefault(_ConnectionHistory);

var _state = require('../../model/state');

var _state2 = _interopRequireDefault(_state);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class NetworkSelection extends _ViewBase2.default {

  constructor(tab) {
    super('Connect to node');
    this._tab = tab;

    // Build menu
    this._continueItem = new _MenuItem2.default('C', 'Continue', 'Connect to Network', this.toConnectionSettings.bind(this));
    const menuItems = [this._continueItem, new _MenuItem2.default('R', 'Recent', 'Recent connections', this.toConnectionHistory.bind(this))];
    this._menu = new _Menu2.default(tab, menuItems, false);

    // Build networks list
    this._networks = ['mainnet', 'testnet', 'regtest', 'nol'];

    const columns = [{
      heading: 'Network',
      width: 25,
      value: network => network
    }];
    this._list = new _List2.default(tab, columns, this._networks, {
      showHeadings: false,
      rowSelection: true,
      onSelect: this.onListSelect.bind(this)
    });
  }

  async onListSelect() {
    this._menu.setSelectedItem(this._continueItem.key);
  }

  render() {
    // Render network list
    this._list.render();

    // Render menu last (for correct cursor positioning)
    this._menu.render(false);
  }

  get _selectedNetwork() {
    const selectedIndex = this._list.selectedRowIndex;
    return this._networks[selectedIndex];
  }

  async toConnectionSettings() {
    try {
      const networkLabel = this._selectedNetwork;
      if (networkLabel === 'mainnet') {
        // Disallow mainnet connections until we have resolved all of
        // the security issues (passwords are currently stored in plain text
        // and we will need to store private keys for tx signing). Also
        // immaturity of cashlib just creates to much risk.
        throw new Error('Sorry, mainnet connections are not secure/supported yet');
      }
      const network = _Network2.default.fromString(networkLabel);
      const connection = new _Connection2.default(network);
      _state2.default.connection = connection;
      this._tab.pushView(new _ConnectionSettings2.default(this._tab));
    } catch (err) {
      this._tab.setError(err.message);
    }
  }

  async toConnectionHistory() {
    try {
      this._tab.replaceView(new _ConnectionHistory2.default(this._tab));
    } catch (err) {
      this._tab.setError(err.message);
    }
  }

  async handle(key) {
    let handled = await this._menu.handle(key);
    if (!handled) {
      handled = await this._list.handle(key);
    }
    return handled;
  }
}
exports.default = NetworkSelection;