'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _MenuForm = require('tooey/lib/MenuForm');

var _MenuForm2 = _interopRequireDefault(_MenuForm);

var _ViewBase = require('tooey/lib/ViewBase');

var _ViewBase2 = _interopRequireDefault(_ViewBase);

var _MenuItem = require('tooey/lib/MenuItem');

var _MenuItem2 = _interopRequireDefault(_MenuItem);

var _Output = require('cashlib/lib/Output');

var _Output2 = _interopRequireDefault(_Output);

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

var _state = require('../../model/state');

var _state2 = _interopRequireDefault(_state);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const fieldIdx = {
  ADDRESS: 0,
  VALUE: 1
};

class TransactionAddP2PKH extends _ViewBase2.default {

  constructor() {
    super('Add P2PKH Output');

    // Form fields
    const fields = [];
    fields[fieldIdx.ADDRESS] = { label: 'Address', default: '', type: 'string' };
    // TODO - enter values in BCH (requires 'float' type to be added tooey)
    fields[fieldIdx.VALUE] = { label: 'Value (Satoshis)', default: '', type: 'integer' };

    // Menu items
    const menuItems = [new _MenuItem2.default('O', 'OK', 'Add output with entered details', this.addOutput.bind(this))];

    this._menuForm = new _MenuForm2.default(_app2.default.activeTab, fields, menuItems);
  }

  async addOutput() {
    try {
      const address = this._menuForm.fields[fieldIdx.ADDRESS].input.value;
      const value = parseInt(this._menuForm.fields[fieldIdx.VALUE].input.value, 10);
      if (!address || !value) {
        _app2.default.setWarning('Enter Address and Value to continue.');
      } else {
        const output = _Output2.default.createP2PKH(address, value);
        _state2.default.transactions.active.addOutput(output);
        _app2.default.popView();
      }
    } catch (err) {
      _app2.default.setError(err.message);
    }
  }

  async handle(key) {
    return this._menuForm.handle(key);
  }

  render() {
    this._menuForm.render();
  }
}
exports.default = TransactionAddP2PKH;