'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _cliui = require('cliui');

var _cliui2 = _interopRequireDefault(_cliui);

var _Transaction = require('cashlib/lib/Transaction');

var _Transaction2 = _interopRequireDefault(_Transaction);

var _ViewBase = require('tooey/lib/ViewBase');

var _ViewBase2 = _interopRequireDefault(_ViewBase);

var _Menu = require('tooey/lib/Menu');

var _Menu2 = _interopRequireDefault(_Menu);

var _MenuItem = require('tooey/lib/MenuItem');

var _MenuItem2 = _interopRequireDefault(_MenuItem);

var _Tab = require('tooey/lib/Tab');

var _Tab2 = _interopRequireDefault(_Tab);

var _TransactionInputs = require('./TransactionInputs');

var _TransactionInputs2 = _interopRequireDefault(_TransactionInputs);

var _TransactionOutputs = require('./TransactionOutputs');

var _TransactionOutputs2 = _interopRequireDefault(_TransactionOutputs);

var _TransactionRaw = require('./TransactionRaw');

var _TransactionRaw2 = _interopRequireDefault(_TransactionRaw);

var _state = require('../../model/state');

var _state2 = _interopRequireDefault(_state);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class TransactionHeader extends _ViewBase2.default {

  constructor(tab) {
    super('Transaction');
    this._tab = tab;
    const items = [new _MenuItem2.default('I', 'Inputs', 'Transaction inputs', async () => tab.pushView(new _TransactionInputs2.default(tab))), new _MenuItem2.default('O', 'Outputs', 'Transaction outputs', async () => tab.pushView(new _TransactionOutputs2.default(tab))), new _MenuItem2.default('R', 'Raw', 'Show raw serialized transaction', async () => tab.pushView(new _TransactionRaw2.default())), new _MenuItem2.default('S', 'Send', 'Broadcast transaction to network', this.send.bind(this))];
    this._menu = new _Menu2.default(tab, items);
  }

  async send() {
    try {
      await _state2.default.rpc.request(`sendrawtransaction ${_state2.default.transactions.active.serialize()}`);
    } catch (err) {
      this._tab.setError(err.message);
    }
  }

  render() {
    // Render transaction info
    const firstColWidth = 10;
    const ui = (0, _cliui2.default)();
    const transaction = _state2.default.transactions.active;
    ui.div({
      text: 'Id: ',
      width: firstColWidth
    }, {
      text: transaction.getId()
    });
    ui.div({
      text: 'Inputs: ',
      width: firstColWidth
    }, {
      text: transaction.inputs.length
    });
    ui.div({
      text: 'Outputs: ',
      width: firstColWidth
    }, {
      text: transaction.outputs.length
    });
    console.log(ui.toString());

    // Render menu last for correct cursor positioning
    this._menu.render(false);
  }

  async handle(key) {
    return this._menu.handle(key);
  }
}
exports.default = TransactionHeader;