'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _MenuForm = require('tooey/lib/MenuForm');

var _MenuForm2 = _interopRequireDefault(_MenuForm);

var _MenuItem = require('tooey/lib/MenuItem');

var _MenuItem2 = _interopRequireDefault(_MenuItem);

require('tooey/lib/Form');

var _ViewBase = require('tooey/lib/ViewBase');

var _ViewBase2 = _interopRequireDefault(_ViewBase);

var _Input = require('cashlib/lib/Input');

var _Input2 = _interopRequireDefault(_Input);

var _stringfu = require('stringfu');

var _GenericText = require('./GenericText');

var _GenericText2 = _interopRequireDefault(_GenericText);

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const fieldIdx = {
  TRANSACTION_ID: 0,
  INPUT_INDEX: 1,
  OUTPUT_TRANSACTION: 2,
  OUTPUT_INDEX: 3,
  SCRIPT: 4
};

class ConnectionSettings extends _ViewBase2.default {

  constructor(input, transactionId, inputIndex) {
    super('Transaction Input');
    this._input = input;

    function blankIfUndefined(value) {
      return value === undefined ? '' : value.toString();
    }

    // Form fields
    const fields = [];
    fields[fieldIdx.TRANSACTION_ID] = { label: 'Transaction Id', default: blankIfUndefined(transactionId), type: 'string' };
    fields[fieldIdx.INPUT_INDEX] = { label: 'Input number', default: blankIfUndefined(inputIndex), type: 'integer' };
    fields[fieldIdx.OUTPUT_TRANSACTION] = { label: 'Output tx', default: input.transactionId, type: 'string' };
    fields[fieldIdx.OUTPUT_INDEX] = { label: 'Output number', default: input.outputIndex.toString(), type: 'integer' };
    fields[fieldIdx.SCRIPT] = { label: 'Signature script', default: (0, _stringfu.fromBytes)(input.signatureScript), type: 'string' };

    this._menuForm = new _MenuForm2.default(_app2.default.activeTab, fields, [new _MenuItem2.default('S', 'Script', 'Show entire signature script', this.toScript.bind(this))], {
      readOnly: true
    });
  }

  async toScript() {
    const scriptText = (0, _stringfu.fromBytes)(this._input.signatureScript);
    // TODO nav to script parser
    const scriptView = new _GenericText2.default('Signature Script', scriptText);
    _app2.default.pushView(scriptView);
  }

  async handle(key) {
    return this._menuForm.handle(key);
  }

  render() {
    this._menuForm.render();
  }
}
exports.default = ConnectionSettings;