'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _Transaction = require('cashlib/lib/Transaction');

var _Transaction2 = _interopRequireDefault(_Transaction);

var _Input = require('cashlib/lib/Input');

var _Input2 = _interopRequireDefault(_Input);

var _ViewBase = require('tooey/lib/ViewBase');

var _ViewBase2 = _interopRequireDefault(_ViewBase);

var _List = require('tooey/lib/List');

var _List2 = _interopRequireDefault(_List);

var _Menu = require('tooey/lib/Menu');

var _Menu2 = _interopRequireDefault(_Menu);

var _Tab = require('tooey/lib/Tab');

var _Tab2 = _interopRequireDefault(_Tab);

var _MenuItem = require('tooey/lib/MenuItem');

var _MenuItem2 = _interopRequireDefault(_MenuItem);

var _TransactionInput = require('./TransactionInput');

var _TransactionInput2 = _interopRequireDefault(_TransactionInput);

var _TransactionAddInput = require('./TransactionAddInput');

var _TransactionAddInput2 = _interopRequireDefault(_TransactionAddInput);

var _state = require('../../model/state');

var _state2 = _interopRequireDefault(_state);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class TransactionInputs extends _ViewBase2.default {

  constructor(tab) {
    super('Transaction Inputs');

    this._tab = tab;

    // Build menu
    const menuItems = [new _MenuItem2.default('S', 'Show', 'Show details for selected input', this.toDetails.bind(this)), new _MenuItem2.default('A', 'Add', 'Add new input', async () => this._tab.pushView(new _TransactionAddInput2.default(tab)))];
    this._menu = new _Menu2.default(tab, menuItems);

    const transaction = _state2.default.transactions.active;
    const columns = [{
      heading: 'Transaction Id',
      width: 64,
      value: input => input.isCoinbase ? 'Coinbase' : input.transactionId
    }, {
      heading: 'Output',
      width: 8,
      value: input => input.isCoinbase ? ' ' : input.outputIndex.toString()
    }, {
      heading: 'Sig?',
      width: 4,
      value: input => input.signatureScript.length ? 'Yes' : ''
    }];

    this._list = new _List2.default(tab, columns, transaction.inputs, {
      rowSelection: true,
      menu: this._menu
    });
  }

  async toDetails() {
    const input = _state2.default.transactions.active.inputs[this._list.selectedRowIndex];
    if (input) {
      this._tab.pushView(new _TransactionInput2.default(input, _state2.default.transactions.active.getId(), this._list.selectedRowIndex));
    } else {
      this._tab.setWarning('No input selected');
    }
  }

  render() {
    // Render outputs list
    this._list.render();

    // Render menu last for correct cursor positioning
    this._menu.render(false);
  }

  async handle(key) {
    let handled = await this._menu.handle(key);
    if (!handled) {
      handled = await this._list.handle(key);
    }
    return handled;
  }
}
exports.default = TransactionInputs;