'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _MenuForm = require('tooey/lib/MenuForm');

var _MenuForm2 = _interopRequireDefault(_MenuForm);

var _MenuItem = require('tooey/lib/MenuItem');

var _MenuItem2 = _interopRequireDefault(_MenuItem);

require('tooey/lib/Form');

var _ViewBase = require('tooey/lib/ViewBase');

var _ViewBase2 = _interopRequireDefault(_ViewBase);

var _Output = require('cashlib/lib/Output');

var _Output2 = _interopRequireDefault(_Output);

var _stringfu = require('stringfu');

var _GenericText = require('./GenericText');

var _GenericText2 = _interopRequireDefault(_GenericText);

var _state = require('../../model/state');

var _state2 = _interopRequireDefault(_state);

var _app = require('../app');

var _app2 = _interopRequireDefault(_app);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const fieldIdx = {
  TRANSACTION_ID: 0,
  OUTPUT_INDEX: 1,
  VALUE: 2,
  ADDRESS: 3,
  TYPE: 4,
  SCRIPT: 5
};
class ConnectionSettings extends _ViewBase2.default {

  constructor(output, transactionId, outputIndex) {
    super('Transaction Output');
    this._output = output;

    function blankIfUndefined(value) {
      return value === undefined ? '' : value.toString();
    }

    // Form fields
    const fields = [];
    fields[fieldIdx.TRANSACTION_ID] = { label: 'Transaction Id', default: blankIfUndefined(transactionId), type: 'string' };
    fields[fieldIdx.OUTPUT_INDEX] = { label: 'Output number', default: blankIfUndefined(outputIndex), type: 'integer' };
    fields[fieldIdx.VALUE] = { label: 'Value', default: output.value.toString(), type: 'integer' };
    const address = output.getAddress(_state2.default.connection.network);
    fields[fieldIdx.ADDRESS] = { label: 'Address', default: blankIfUndefined(address), type: 'string' };
    fields[fieldIdx.TYPE] = { label: 'Type', default: blankIfUndefined(output.scriptType), type: 'string' };
    fields[fieldIdx.SCRIPT] = { label: 'Public key script', default: (0, _stringfu.fromBytes)(output.pubKeyScript), type: 'string' };

    this._menuForm = new _MenuForm2.default(_app2.default.activeTab, fields, [new _MenuItem2.default('S', 'Script', 'Show entire public key script', this.toScript.bind(this))], {
      readOnly: true
    });
  }

  async toScript() {
    const scriptText = (0, _stringfu.fromBytes)(this._output._pubKeyScript);
    // TODO nav to script parser
    const scriptView = new _GenericText2.default('Public Key Script', scriptText);
    _app2.default.pushView(scriptView);
  }

  async handle(key) {
    return this._menuForm.handle(key);
  }

  render() {
    this._menuForm.render();
  }
}
exports.default = ConnectionSettings;